# coding: utf-8
from enum import Enum, unique


@unique
class PanType(Enum):
    
    PLAIN = "PLAIN"
    PLAIN_GOOGLE_PAY = "PLAIN_GOOGLE_PAY"
    SCHEME_TOKEN = "SCHEME_TOKEN"
    SCHEME_TOKEN_CLICK_TO_PAY = "SCHEME_TOKEN_CLICK_TO_PAY"
    DEVICE_TOKEN_APPLE_PAY = "DEVICE_TOKEN_APPLE_PAY"
    DEVICE_TOKEN_GOOGLE_PAY = "DEVICE_TOKEN_GOOGLE_PAY"
    DEVICE_TOKEN_SAMSUNG_PAY = "DEVICE_TOKEN_SAMSUNG_PAY"
    DEVICE_TOKEN_ANDROID_PAY = "DEVICE_TOKEN_ANDROID_PAY"

