# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentTerminal:

    swagger_types = {
    
        'configuration_version': 'PaymentTerminalConfigurationVersion',
        'default_currency': 'str',
        'device_name': 'str',
        'device_serial_number': 'str',
        'external_id': 'str',
        'id': 'int',
        'identifier': 'str',
        'linked_space_id': 'int',
        'location_version': 'PaymentTerminalLocationVersion',
        'name': 'str',
        'planned_purge_date': 'datetime',
        'state': 'PaymentTerminalState',
        'type': 'PaymentTerminalType',
        'version': 'int',
    }

    attribute_map = {
        'configuration_version': 'configurationVersion','default_currency': 'defaultCurrency','device_name': 'deviceName','device_serial_number': 'deviceSerialNumber','external_id': 'externalId','id': 'id','identifier': 'identifier','linked_space_id': 'linkedSpaceId','location_version': 'locationVersion','name': 'name','planned_purge_date': 'plannedPurgeDate','state': 'state','type': 'type','version': 'version',
    }

    
    _configuration_version = None
    _default_currency = None
    _device_name = None
    _device_serial_number = None
    _external_id = None
    _id = None
    _identifier = None
    _linked_space_id = None
    _location_version = None
    _name = None
    _planned_purge_date = None
    _state = None
    _type = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.configuration_version = kwargs.get('configuration_version', None)
        self.default_currency = kwargs.get('default_currency', None)
        self.device_name = kwargs.get('device_name', None)
        self.device_serial_number = kwargs.get('device_serial_number', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.identifier = kwargs.get('identifier', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.location_version = kwargs.get('location_version', None)
        self.name = kwargs.get('name', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.type = kwargs.get('type', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def configuration_version(self):
        """Gets the configuration_version of this PaymentTerminal.

            The configuration that is assigned to the terminal and determines how it works.

        :return: The configuration_version of this PaymentTerminal.
        :rtype: PaymentTerminalConfigurationVersion
        """
        return self._configuration_version

    @configuration_version.setter
    def configuration_version(self, configuration_version):
        """Sets the configuration_version of this PaymentTerminal.

            The configuration that is assigned to the terminal and determines how it works.

        :param configuration_version: The configuration_version of this PaymentTerminal.
        :type: PaymentTerminalConfigurationVersion
        """

        self._configuration_version = configuration_version
    
    @property
    def default_currency(self):
        """Gets the default_currency of this PaymentTerminal.

            The default currency of the terminal.

        :return: The default_currency of this PaymentTerminal.
        :rtype: str
        """
        return self._default_currency

    @default_currency.setter
    def default_currency(self, default_currency):
        """Sets the default_currency of this PaymentTerminal.

            The default currency of the terminal.

        :param default_currency: The default_currency of this PaymentTerminal.
        :type: str
        """

        self._default_currency = default_currency
    
    @property
    def device_name(self):
        """Gets the device_name of this PaymentTerminal.

            The name of the device that is currently linked to the payment terminal.

        :return: The device_name of this PaymentTerminal.
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this PaymentTerminal.

            The name of the device that is currently linked to the payment terminal.

        :param device_name: The device_name of this PaymentTerminal.
        :type: str
        """

        self._device_name = device_name
    
    @property
    def device_serial_number(self):
        """Gets the device_serial_number of this PaymentTerminal.

            The serial number of the device that is currently linked to the payment terminal.

        :return: The device_serial_number of this PaymentTerminal.
        :rtype: str
        """
        return self._device_serial_number

    @device_serial_number.setter
    def device_serial_number(self, device_serial_number):
        """Sets the device_serial_number of this PaymentTerminal.

            The serial number of the device that is currently linked to the payment terminal.

        :param device_serial_number: The device_serial_number of this PaymentTerminal.
        :type: str
        """

        self._device_serial_number = device_serial_number
    
    @property
    def external_id(self):
        """Gets the external_id of this PaymentTerminal.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :return: The external_id of this PaymentTerminal.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this PaymentTerminal.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :param external_id: The external_id of this PaymentTerminal.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this PaymentTerminal.

            A unique identifier for the object.

        :return: The id of this PaymentTerminal.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentTerminal.

            A unique identifier for the object.

        :param id: The id of this PaymentTerminal.
        :type: int
        """

        self._id = id
    
    @property
    def identifier(self):
        """Gets the identifier of this PaymentTerminal.

            The unique identifier of the terminal, that is displayed on the device.

        :return: The identifier of this PaymentTerminal.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this PaymentTerminal.

            The unique identifier of the terminal, that is displayed on the device.

        :param identifier: The identifier of this PaymentTerminal.
        :type: str
        """

        self._identifier = identifier
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentTerminal.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this PaymentTerminal.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentTerminal.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this PaymentTerminal.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def location_version(self):
        """Gets the location_version of this PaymentTerminal.

            The physical location where the terminal is used.

        :return: The location_version of this PaymentTerminal.
        :rtype: PaymentTerminalLocationVersion
        """
        return self._location_version

    @location_version.setter
    def location_version(self, location_version):
        """Sets the location_version of this PaymentTerminal.

            The physical location where the terminal is used.

        :param location_version: The location_version of this PaymentTerminal.
        :type: PaymentTerminalLocationVersion
        """

        self._location_version = location_version
    
    @property
    def name(self):
        """Gets the name of this PaymentTerminal.

            The name used to identify the payment terminal.

        :return: The name of this PaymentTerminal.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentTerminal.

            The name used to identify the payment terminal.

        :param name: The name of this PaymentTerminal.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this PaymentTerminal.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this PaymentTerminal.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this PaymentTerminal.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this PaymentTerminal.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this PaymentTerminal.

            The object's current state.

        :return: The state of this PaymentTerminal.
        :rtype: PaymentTerminalState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentTerminal.

            The object's current state.

        :param state: The state of this PaymentTerminal.
        :type: PaymentTerminalState
        """

        self._state = state
    
    @property
    def type(self):
        """Gets the type of this PaymentTerminal.

            The type of the payment terminal.

        :return: The type of this PaymentTerminal.
        :rtype: PaymentTerminalType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PaymentTerminal.

            The type of the payment terminal.

        :param type: The type of this PaymentTerminal.
        :type: PaymentTerminalType
        """

        self._type = type
    
    @property
    def version(self):
        """Gets the version of this PaymentTerminal.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this PaymentTerminal.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentTerminal.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this PaymentTerminal.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentTerminal, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentTerminal):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
